@@ -29,13 +29,19 @@
 
 #include "converter/immutable_converter.h"
 
+#include "base/base.h"
+#include "base/singleton.h"
 #include "base/util.h"
 #include "config/config.pb.h"
 #include "config/config_handler.h"
-#include "converter/segments.h"
 #include "converter/lattice.h"
+#include "converter/segmenter.h"
+#include "converter/segments.h"
+#include "data_manager/user_pos_manager.h"
 #include "dictionary/dictionary_interface.h"
+#include "dictionary/pos_matcher.h"
 #include "dictionary/suffix_dictionary.h"
+#include "dictionary/suppression_dictionary.h"
 #include "testing/base/public/gunit.h"
 
 DECLARE_string(test_tmpdir);
@@ -189,16 +195,18 @@ TEST_F(ImmutableConverterTest, PredictiveNodesOnlyForConversionKey) {
   scoped_ptr<KeyCheckDictionary> dictionary(
       // "ないか"
       new KeyCheckDictionary("\xe3\x81\xaa\xe3\x81\x84\xe3\x81\x8b"));
-  DictionaryFactory::SetDictionary(dictionary.get());
-  SuffixDictionaryFactory::SetSuffixDictionary(dictionary.get());
-
-  GetConverter()->MakeLatticeNodesForPredictiveNodes(
-      &lattice, &segments);
 
+  scoped_ptr<ImmutableConverterImpl> converter(
+      new ImmutableConverterImpl(
+          dictionary.get(),
+          dictionary.get(),
+          Singleton<SuppressionDictionary>::get(),
+          ConnectorFactory::GetConnector(),
+          Singleton<Segmenter>::get(),
+          Singleton<POSMatcher>::get(),
+          UserPosManager::GetUserPosManager()->GetPosGroup()));
+  converter->MakeLatticeNodesForPredictiveNodes(&lattice, &segments);
   EXPECT_FALSE(dictionary->received_target_query());
-
-  DictionaryFactory::SetDictionary(NULL);
-  SuffixDictionaryFactory::SetSuffixDictionary(NULL);
 }
 
 TEST_F(ImmutableConverterTest, AddPredictiveNodes) {
@@ -222,15 +230,127 @@ TEST_F(ImmutableConverterTest, AddPredictiveNodes) {
   scoped_ptr<KeyCheckDictionary> dictionary(
       // "しま"
       new KeyCheckDictionary("\xe3\x81\x97\xe3\x81\xbe"));
-  DictionaryFactory::SetDictionary(dictionary.get());
-  SuffixDictionaryFactory::SetSuffixDictionary(dictionary.get());
-
-  GetConverter()->MakeLatticeNodesForPredictiveNodes(
-      &lattice, &segments);
 
+  scoped_ptr<ImmutableConverterImpl> converter(
+      new ImmutableConverterImpl(
+          dictionary.get(),
+          dictionary.get(),
+          Singleton<SuppressionDictionary>::get(),
+          ConnectorFactory::GetConnector(),
+          Singleton<Segmenter>::get(),
+          Singleton<POSMatcher>::get(),
+          UserPosManager::GetUserPosManager()->GetPosGroup()));
+  converter->MakeLatticeNodesForPredictiveNodes(&lattice, &segments);
   EXPECT_TRUE(dictionary->received_target_query());
+}
 
-  DictionaryFactory::SetDictionary(NULL);
-  SuffixDictionaryFactory::SetSuffixDictionary(NULL);
+class ConnectionTypeHandlerTest : public ::testing::Test {
+ protected:
+  void MakeGroup(const Segments &segments, vector<uint16> *group) {
+    group->clear();
+    for (size_t i = 0; i < segments.segments_size(); ++i) {
+      for (size_t j = 0; j < segments.segment(i).key().size(); ++j) {
+        group->push_back(static_cast<uint16>(i));
+      }
+    }
+    group->push_back(static_cast<uint16>(segments.segments_size() - 1));
+  }
+};
+
+TEST_F(ConnectionTypeHandlerTest, GetConnectionType) {
+  scoped_ptr<ImmutableConverterImpl> converter(
+      new ImmutableConverterImpl(
+          DictionaryFactory::GetDictionary(),
+          SuffixDictionaryFactory::GetSuffixDictionary(),
+          Singleton<SuppressionDictionary>::get(),
+          ConnectorFactory::GetConnector(),
+          Singleton<Segmenter>::get(),
+          Singleton<POSMatcher>::get(),
+          UserPosManager::GetUserPosManager()->GetPosGroup()));
+
+  Segments segments;
+  segments.set_request_type(Segments::CONVERSION);
+
+  Segment *segment = segments.add_segment();
+  segment->set_segment_type(Segment::HISTORY);
+  // "あやうく"
+  segment->set_key("\xe3\x81\x82\xe3\x82\x84\xe3\x81\x86\xe3\x81\x8f");
+  Segment::Candidate *candidate = segment->add_candidate();
+  // "あやうく"
+  candidate->key = "\xe3\x81\x82\xe3\x82\x84\xe3\x81\x86\xe3\x81\x8f";
+  // "危うく"
+  candidate->value = "\xe5\x8d\xb1\xe3\x81\x86\xe3\x81\x8f";
+
+  segment = segments.add_segment();
+  segment->set_segment_type(Segment::HISTORY);
+  // "きき"
+  segment->set_key("\xe3\x81\x8d\xe3\x81\x8d");
+  candidate = segment->add_candidate();
+  // "きき"
+  candidate->key = "\xe3\x81\x8d\xe3\x81\x8d";
+  // "危機"
+  candidate->value = "\xe5\x8d\xb1\xe6\xa9\x9f";
+
+  segment = segments.add_segment();
+  segment->set_segment_type(Segment::FIXED_BOUNDARY);
+  // "いっぱつの"
+  segment->set_key(
+      "\xe3\x81\x84\xe3\x81\xa3\xe3\x81\xb1\xe3\x81\xa4\xe3\x81\xae");
+
+  segment = segments.add_segment();
+  segment->set_segment_type(Segment::FREE);
+  // "ところで"
+  segment->set_key("\xe3\x81\xa8\xe3\x81\x93\xe3\x82\x8d\xe3\x81\xa7");
+
+  vector<uint16> group;
+  MakeGroup(segments, &group);
+
+  Lattice lattice;
+  // "あやうくききいっぱつのところで"
+  lattice.SetKey(
+      "\xe3\x81\x82\xe3\x82\x84\xe3\x81\x86\xe3\x81\x8f\xe3\x81\x8d\xe3\x81\x8d"
+      "\xe3\x81\x84\xe3\x81\xa3\xe3\x81\xb1\xe3\x81\xa4\xe3\x81\xae\xe3\x81\xa8"
+      "\xe3\x81\x93\xe3\x82\x8d\xe3\x81\xa7");
+  converter->MakeLattice(&lattice, &segments);
+
+  SegmenterInterface *segmenter = Singleton<Segmenter>::get();
+
+  ConnectionTypeHandler connection_type_handler(
+      group, &segments, segmenter);
+  bool connected_found = false;
+  bool weak_connected_found = false;
+  bool not_connected_found = false;
+
+  for (size_t pos = 0; pos <= lattice.key().size(); ++pos) {
+    for (Node *rnode = lattice.begin_nodes(pos);
+         rnode != NULL; rnode = rnode->bnext) {
+      connection_type_handler.SetRNode(rnode);
+      for (Node *lnode = lattice.end_nodes(pos);
+           lnode != NULL; lnode = lnode->enext) {
+        ConnectionTypeHandler::ConnectionType naive_result =
+            ConnectionTypeHandler::GetConnectionTypeForUnittest(
+                lnode, rnode, group, &segments, segmenter);
+        ConnectionTypeHandler::ConnectionType result =
+            connection_type_handler.GetConnectionType(lnode);
+        EXPECT_EQ(naive_result, result);
+        switch (naive_result) {
+          case ConnectionTypeHandler::CONNECTED:
+            connected_found = true;
+            break;
+          case ConnectionTypeHandler::WEAK_CONNECTED:
+            weak_connected_found = true;
+            break;
+          case ConnectionTypeHandler::NOT_CONNECTED:
+            not_connected_found = true;
+            break;
+          default:
+            CHECK(false) << "Should not come here.";
+        }
+      }
+    }
+  }
+  EXPECT_TRUE(connected_found);
+  EXPECT_TRUE(weak_connected_found);
+  EXPECT_TRUE(not_connected_found);
 }
 }  // namespace mozc
