@@ -34,6 +34,7 @@
 #include <vector>
 #include <string>
 #include "base/base.h"
+#include "base/util.h"
 #include "converter/lattice.h"
 
 namespace mozc {
@@ -58,6 +59,30 @@ class Segment {
   };
 
   struct Candidate {
+    enum Attribute {
+      DEFAULT_ATTRIBUTE = 0,
+      BEST_CANDIDATE = 1,        // this was the best candidate before learning
+      RERANKED = 2,                // this candidate was reranked by user
+      NO_HISTORY_LEARNING = 4,     // don't save it in history
+      NO_SUGGEST_LEARNING = 8,     // don't save it in suggestion
+      NO_LEARNING = (4 | 8),       // NO_HISTORY_LEARNING | NO_SUGGEST_LEARNING
+      CONTEXT_SENSITIVE = 16,      // learn it with left/right context
+      SPELLING_CORRECTION = 32,    // has "did you mean"
+      NO_VARIANTS_EXPANSION = 64,  // No need to have full/half width expansion
+      NO_EXTRA_DESCRIPTION = 128,  // No need to have extra descriptions.
+      REALTIME_CONVERSION = 256,   // was generated by real-time conversion
+      USER_DICTIONARY = 512,       // contains tokens in user dictionary.
+      COMMAND_CANDIDATE = 1024,    // command candidate. e.g., incognito mode.
+    };
+
+    enum Command {
+      DEFAULT_COMMAND = 0,
+      ENABLE_INCOGNITO_MODE,      // enables "incognito mode".
+      DISABLE_INCOGNITO_MODE,     // disables "incognito mode".
+      ENABLE_PRESENTATION_MODE,   // enables "presentation mode".
+      DISABLE_PRESENTATION_MODE,  // disables "presentation mode".
+    };
+
     string key;         // reading
     string value;       // surface form
     string content_key;
@@ -98,11 +123,11 @@ class Segment {
 
     // Candidate style. This is not a bit-field.
     // The style is defined in enum |Style|.
-    uint32 style;
+    Util::NumberString::Style style;
 
     // Command of this candidate. This is not a bit-field.
     // The style is defined in enum |Command|.
-    uint32 command;
+    Command command;
 
     void Init() {
       key.clear();
@@ -121,52 +146,14 @@ class Segment {
       rid = 0;
       usage_id = 0;
       attributes = 0;
-      style = 0;
-      command = 0;
+      style = Util::NumberString::DEFAULT_STYLE;
+      command = DEFAULT_COMMAND;
     }
 
     Candidate() : cost(0), wcost(0), structure_cost(0),
-                  lid(0), rid(0),
-                  attributes(0), style(0), command(0) {}
-
-    enum Attribute {
-      DEFAULT_ATTRIBUTE = 0,
-      BEST_CANDIDATE = 1,        // this was the best candidate before learning
-      RERANKED = 2,                // this candidate was reranked by user
-      NO_HISTORY_LEARNING = 4,     // don't save it in history
-      NO_SUGGEST_LEARNING = 8,     // don't save it in suggestion
-      NO_LEARNING = (4 | 8),       // NO_HISTORY_LEARNING | NO_SUGGEST_LEARNING
-      CONTEXT_SENSITIVE = 16,      // learn it with left/right context
-      SPELLING_CORRECTION = 32,    // has "did you mean"
-      NO_VARIANTS_EXPANSION = 64,  // No need to have full/half width expansion
-      NO_EXTRA_DESCRIPTION = 128,  // No need to have extra descriptions.
-      REALTIME_CONVERSION = 256,   // was generated by real-time conversion
-      USER_DICTIONARY = 512,       // contains tokens in user dictionary.
-      COMMAND_CANDIDATE = 1024,    // command candidate. e.g., incognito mode.
-    };
-
-    enum COMMAND {
-      DEFAULT_COMMAND = 0,
-      ENABLE_INCOGNITO_MODE,      // enables "incognito mode".
-      DISABLE_INCOGNITO_MODE,     // disables "incognito mode".
-      ENABLE_PRESENTATION_MODE,   // enables "presentation mode".
-      DISABLE_PRESENTATION_MODE,  // disables "presentation mode".
-    };
-
-    enum Style {
-      DEFAULT_STYLE= 0,
-      NUMBER_SEPARATED_ARABIC_HALFWIDTH,
-      NUMBER_SEPARATED_ARABIC_FULLWIDTH,
-      NUMBER_KANJI,
-      NUMBER_OLD_KANJI,
-      NUMBER_ROMAN_CAPITAL,
-      NUMBER_ROMAN_SMALL,
-      NUMBER_CIRCLED,
-      NUMBER_HEX,
-      NUMBER_OCT,
-      NUMBER_BIN,
-      NUMBER_KANJI_ARABIC,  // "二〇〇"
-    };
+                  lid(0), rid(0), attributes(0),
+                  style(Util::NumberString::DEFAULT_STYLE),
+                  command(DEFAULT_COMMAND) {}
 
     // return functional key
     // functional_key =
@@ -363,9 +350,6 @@ class Segments {
   bool resized() const;
   void set_resized(bool resized);
 
-  const composer::Composer *composer() const;
-  void set_composer(const composer::Composer *composer);
-
   // Removes specified number of characters at the end of history segments.
   void RemoveTailOfHistorySegments(size_t num_of_characters);
 
@@ -402,7 +386,6 @@ class Segments {
   scoped_ptr<ObjectPool<Segment> > pool_;
   deque<Segment *> segments_;
   vector<RevertEntry> revert_entries_;
-  const composer::Composer *composer_;
   scoped_ptr<Lattice> cached_lattice_;
 
   DISALLOW_COPY_AND_ASSIGN(Segments);
