@@ -36,12 +36,10 @@
 #include "base/logging.h"
 #include "base/version.h"
 #include "config/config_handler.h"
-#include "languages/hangul/lang_dep_spec.h"
 #include "languages/hangul/hangul_session_factory.h"
 #include "languages/hangul/session.h"
 #include "languages/hangul/unix/ibus/config_updater.h"
 #include "languages/hangul/unix/ibus/main.h"
-#include "languages/global_language_spec.h"
 #include "session/session_factory_manager.h"
 #include "unix/ibus/config_util.h"
 #include "unix/ibus/mozc_engine.h"
@@ -124,8 +122,6 @@ void InitIBusComponent(bool executed_by_ibus_daemon) {
 
 int main(gint argc, gchar **argv) {
   InitGoogle(argv[0], &argc, &argv, true);
-  mozc::hangul::LangDepSpecHangul lang_spec;
-  mozc::language::GlobalLanguageSpec::SetLanguageDependentSpec(&lang_spec);
 #ifdef OS_CHROMEOS
   mozc::hangul::HangulSessionFactory session_factory;
   mozc::session::SessionFactoryManager::SetSessionFactory(&session_factory);
