@@ -36,6 +36,7 @@
 #include "base/base.h"
 #include "base/version.h"
 #include "base/singleton.h"
+#include "converter/conversion_request.h"
 #include "converter/segments.h"
 #include "session/commands.pb.h"
 
@@ -115,7 +116,8 @@ int VersionRewriter::capability() const {
   return RewriterInterface::CONVERSION;
 }
 
-bool VersionRewriter::Rewrite(Segments *segments) const {
+bool VersionRewriter::Rewrite(const ConversionRequest &request,
+                              Segments *segments) const {
   bool result = false;
   for (size_t i = segments->history_segments_size();
        i < segments->segments_size(); ++i) {
